@@ -1,23 +1,8 @@
 /*
- *   Copyright (C) 2015, 2016 Ivan Cukic <ivan.cukic(at)kde.org>
- *
- *   This library is free software; you can redistribute it and/or
- *   modify it under the terms of the GNU Lesser General Public
- *   License as published by the Free Software Foundation; either
- *   version 2.1 of the License, or (at your option) version 3, or any
- *   later version accepted by the membership of KDE e.V. (or its
- *   successor approved by the membership of KDE e.V.), which shall
- *   act as a proxy defined in Section 6 of version 3 of the license.
- *
- *   This library is distributed in the hope that it will be useful,
- *   but WITHOUT ANY WARRANTY; without even the implied warranty of
- *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
- *   Lesser General Public License for more details.
- *
- *   You should have received a copy of the GNU Lesser General Public
- *   License along with this library.
- *   If not, see <http://www.gnu.org/licenses/>.
- */
+    SPDX-FileCopyrightText: 2015, 2016 Ivan Cukic <ivan.cukic(at)kde.org>
+
+    SPDX-License-Identifier: LGPL-2.1-only OR LGPL-3.0-only OR LicenseRef-KDE-Accepted-LGPL
+*/
 
 // Self
 #include "resultmodel.h"
@@ -982,7 +967,8 @@ QHash<int, QByteArray> ResultModel::roleNames() const
         { FirstUpdateRole      , "created" },
         { LastUpdateRole       , "modified" },
         { LinkStatusRole       , "linkStatus" },
-        { LinkedActivitiesRole , "linkedActivities" }
+        { LinkedActivitiesRole , "linkedActivities" },
+        { MimeType             , "mimeType" },
     };
 }
 
@@ -1009,6 +995,7 @@ QVariant ResultModel::data(const QModelIndex &item, int role) const
          : role == LastUpdateRole       ? result.lastUpdate()
          : role == LinkStatusRole       ? result.linkStatus()
          : role == LinkedActivitiesRole ? result.linkedActivities()
+         : role == MimeType             ? result.mimetype()
          : QVariant()
          ;
 }
